Class: PulpPythonClient::PatchedpythonPythonRepository

Inherits:
Object
  • Object
show all
Defined in:
lib/pulp_python_client/models/patchedpython_python_repository.rb

Overview

Serializer for Python Repositories.

Instance Attribute Summary collapse

Class Method Summary collapse

Instance Method Summary collapse

Constructor Details

#initialize(attributes = {}) ⇒ PatchedpythonPythonRepository

Initializes the object

Parameters:

  • attributes (Hash) (defaults to: {})

    Model attributes in the form of hash



92
93
94
95
96
97
98
99
100
101
102
103
104
105
106
107
108
109
110
111
112
113
114
115
116
117
118
119
120
121
122
123
124
125
126
127
128
129
130
131
132
133
134
135
136
137
138
139
140
141
142
143
144
145
146
147
148
# File 'lib/pulp_python_client/models/patchedpython_python_repository.rb', line 92

def initialize(attributes = {})
  if (!attributes.is_a?(Hash))
    fail ArgumentError, "The input argument (attributes) must be a hash in `PulpPythonClient::PatchedpythonPythonRepository` initialize method"
  end

  # check to see if the attribute exists and convert string to symbol for hash key
  attributes = attributes.each_with_object({}) { |(k, v), h|
    if (!self.class.attribute_map.key?(k.to_sym))
      fail ArgumentError, "`#{k}` is not a valid attribute in `PulpPythonClient::PatchedpythonPythonRepository`. Please check the name to make sure it's valid. List of attributes: " + self.class.attribute_map.keys.inspect
    end
    h[k.to_sym] = v
  }

  if attributes.key?(:'pulp_labels')
    if (value = attributes[:'pulp_labels']).is_a?(Hash)
      self.pulp_labels = value
    end
  end

  if attributes.key?(:'name')
    self.name = attributes[:'name']
  end

  if attributes.key?(:'description')
    self.description = attributes[:'description']
  end

  if attributes.key?(:'retain_repo_versions')
    self.retain_repo_versions = attributes[:'retain_repo_versions']
  end

  if attributes.key?(:'retain_checkpoints')
    self.retain_checkpoints = attributes[:'retain_checkpoints']
  end

  if attributes.key?(:'remote')
    self.remote = attributes[:'remote']
  end

  if attributes.key?(:'autopublish')
    self.autopublish = attributes[:'autopublish']
  else
    self.autopublish = false
  end

  if attributes.key?(:'allow_package_substitution')
    self.allow_package_substitution = attributes[:'allow_package_substitution']
  else
    self.allow_package_substitution = true
  end

  if attributes.key?(:'error_on_reject')
    self.error_on_reject = attributes[:'error_on_reject']
  else
    self.error_on_reject = true
  end
end

Instance Attribute Details

#allow_package_substitutionObject

Whether to allow package substitution (replacing existing packages with packages that have the same filename but a different checksum). When False, any new repository version that would cause such a substitution will be rejected. This applies to all repository version creation paths including uploads, modify, and sync. When True (the default), package substitution is allowed.



40
41
42
# File 'lib/pulp_python_client/models/patchedpython_python_repository.rb', line 40

def allow_package_substitution
  @allow_package_substitution
end

#autopublishObject

Whether to automatically create publications for new repository versions, and update any distributions pointing to this repository. [Deprecated]



37
38
39
# File 'lib/pulp_python_client/models/patchedpython_python_repository.rb', line 37

def autopublish
  @autopublish
end

#descriptionObject

An optional description.



25
26
27
# File 'lib/pulp_python_client/models/patchedpython_python_repository.rb', line 25

def description
  @description
end

#error_on_rejectObject

Whether to fail the entire repository version when packages are rejected by the package substitution or blocklist policies. When True (the default), a ValidationError is raised and no packages from the request are added. When False, rejected packages are skipped and remaining packages are added; skipped packages are recorded in a task progress report.



43
44
45
# File 'lib/pulp_python_client/models/patchedpython_python_repository.rb', line 43

def error_on_reject
  @error_on_reject
end

#nameObject

A unique name for this repository.



22
23
24
# File 'lib/pulp_python_client/models/patchedpython_python_repository.rb', line 22

def name
  @name
end

#pulp_labelsObject

Returns the value of attribute pulp_labels.



19
20
21
# File 'lib/pulp_python_client/models/patchedpython_python_repository.rb', line 19

def pulp_labels
  @pulp_labels
end

#remoteObject

An optional remote to use by default when syncing.



34
35
36
# File 'lib/pulp_python_client/models/patchedpython_python_repository.rb', line 34

def remote
  @remote
end

#retain_checkpointsObject

Retain X checkpoint publications for the repository. Default is null which retains all checkpoints.



31
32
33
# File 'lib/pulp_python_client/models/patchedpython_python_repository.rb', line 31

def retain_checkpoints
  @retain_checkpoints
end

#retain_repo_versionsObject

Retain X versions of the repository. Default is null which retains all versions.



28
29
30
# File 'lib/pulp_python_client/models/patchedpython_python_repository.rb', line 28

def retain_repo_versions
  @retain_repo_versions
end

Class Method Details

._deserialize(type, value) ⇒ Object

Deserializes the data based on type

Parameters:

  • string

    type Data type

  • string

    value Value to be deserialized

Returns:

  • (Object)

    Deserialized data



284
285
286
287
288
289
290
291
292
293
294
295
296
297
298
299
300
301
302
303
304
305
306
307
308
309
310
311
312
313
314
315
316
317
318
319
320
321
# File 'lib/pulp_python_client/models/patchedpython_python_repository.rb', line 284

def self._deserialize(type, value)
  case type.to_sym
  when :Time
    Time.parse(value)
  when :Date
    Date.parse(value)
  when :String
    value.to_s
  when :Integer
    value.to_i
  when :Float
    value.to_f
  when :Boolean
    if value.to_s =~ /\A(true|t|yes|y|1)\z/i
      true
    else
      false
    end
  when :Object
    # generic object (usually a Hash), return directly
    value
  when /\AArray<(?<inner_type>.+)>\z/
    inner_type = Regexp.last_match[:inner_type]
    value.map { |v| _deserialize(inner_type, v) }
  when /\AHash<(?<k_type>.+?), (?<v_type>.+)>\z/
    k_type = Regexp.last_match[:k_type]
    v_type = Regexp.last_match[:v_type]
    {}.tap do |hash|
      value.each do |k, v|
        hash[_deserialize(k_type, k)] = _deserialize(v_type, v)
      end
    end
  else # model
    # models (e.g. Pet) or oneOf
    klass = PulpPythonClient.const_get(type)
    klass.respond_to?(:openapi_any_of) || klass.respond_to?(:openapi_one_of) ? klass.build(value) : klass.build_from_hash(value)
  end
end

.acceptable_attributesObject

Returns all the JSON keys this model knows about



61
62
63
# File 'lib/pulp_python_client/models/patchedpython_python_repository.rb', line 61

def self.acceptable_attributes
  attribute_map.values
end

.attribute_mapObject

Attribute mapping from ruby-style variable name to JSON key.



46
47
48
49
50
51
52
53
54
55
56
57
58
# File 'lib/pulp_python_client/models/patchedpython_python_repository.rb', line 46

def self.attribute_map
  {
    :'pulp_labels' => :'pulp_labels',
    :'name' => :'name',
    :'description' => :'description',
    :'retain_repo_versions' => :'retain_repo_versions',
    :'retain_checkpoints' => :'retain_checkpoints',
    :'remote' => :'remote',
    :'autopublish' => :'autopublish',
    :'allow_package_substitution' => :'allow_package_substitution',
    :'error_on_reject' => :'error_on_reject'
  }
end

.build_from_hash(attributes) ⇒ Object

Builds the object from hash

Parameters:

  • attributes (Hash)

    Model attributes in the form of hash

Returns:

  • (Object)

    Returns the model itself



260
261
262
263
264
265
266
267
268
269
270
271
272
273
274
275
276
277
278
# File 'lib/pulp_python_client/models/patchedpython_python_repository.rb', line 260

def self.build_from_hash(attributes)
  return nil unless attributes.is_a?(Hash)
  attributes = attributes.transform_keys(&:to_sym)
  transformed_hash = {}
  openapi_types.each_pair do |key, type|
    if attributes.key?(attribute_map[key]) && attributes[attribute_map[key]].nil?
      transformed_hash["#{key}"] = nil
    elsif type =~ /\AArray<(.*)>/i
      # check to ensure the input is an array given that the attribute
      # is documented as an array but the input is not
      if attributes[attribute_map[key]].is_a?(Array)
        transformed_hash["#{key}"] = attributes[attribute_map[key]].map { |v| _deserialize($1, v) }
      end
    elsif !attributes[attribute_map[key]].nil?
      transformed_hash["#{key}"] = _deserialize(type, attributes[attribute_map[key]])
    end
  end
  new(transformed_hash)
end

.openapi_nullableObject

List of attributes with nullable: true



81
82
83
84
85
86
87
88
# File 'lib/pulp_python_client/models/patchedpython_python_repository.rb', line 81

def self.openapi_nullable
  Set.new([
    :'description',
    :'retain_repo_versions',
    :'retain_checkpoints',
    :'remote',
  ])
end

.openapi_typesObject

Attribute type mapping.



66
67
68
69
70
71
72
73
74
75
76
77
78
# File 'lib/pulp_python_client/models/patchedpython_python_repository.rb', line 66

def self.openapi_types
  {
    :'pulp_labels' => :'Hash<String, String>',
    :'name' => :'String',
    :'description' => :'String',
    :'retain_repo_versions' => :'Integer',
    :'retain_checkpoints' => :'Integer',
    :'remote' => :'String',
    :'autopublish' => :'Boolean',
    :'allow_package_substitution' => :'Boolean',
    :'error_on_reject' => :'Boolean'
  }
end

Instance Method Details

#==(o) ⇒ Object

Checks equality by comparing each attribute.

Parameters:

  • Object (Object)

    to be compared



231
232
233
234
235
236
237
238
239
240
241
242
243
# File 'lib/pulp_python_client/models/patchedpython_python_repository.rb', line 231

def ==(o)
  return true if self.equal?(o)
  self.class == o.class &&
      pulp_labels == o.pulp_labels &&
      name == o.name &&
      description == o.description &&
      retain_repo_versions == o.retain_repo_versions &&
      retain_checkpoints == o.retain_checkpoints &&
      remote == o.remote &&
      autopublish == o.autopublish &&
      allow_package_substitution == o.allow_package_substitution &&
      error_on_reject == o.error_on_reject
end

#_to_hash(value) ⇒ Hash

Outputs non-array value in the form of hash For object, use to_hash. Otherwise, just return the value

Parameters:

  • value (Object)

    Any valid value

Returns:

  • (Hash)

    Returns the value in the form of hash



355
356
357
358
359
360
361
362
363
364
365
366
367
# File 'lib/pulp_python_client/models/patchedpython_python_repository.rb', line 355

def _to_hash(value)
  if value.is_a?(Array)
    value.compact.map { |v| _to_hash(v) }
  elsif value.is_a?(Hash)
    {}.tap do |hash|
      value.each { |k, v| hash[k] = _to_hash(v) }
    end
  elsif value.respond_to? :to_hash
    value.to_hash
  else
    value
  end
end

#eql?(o) ⇒ Boolean

Parameters:

  • Object (Object)

    to be compared

Returns:

  • (Boolean)

See Also:

  • `==` method


247
248
249
# File 'lib/pulp_python_client/models/patchedpython_python_repository.rb', line 247

def eql?(o)
  self == o
end

#hashInteger

Calculates hash code according to all attributes.

Returns:

  • (Integer)

    Hash code



253
254
255
# File 'lib/pulp_python_client/models/patchedpython_python_repository.rb', line 253

def hash
  [pulp_labels, name, description, retain_repo_versions, retain_checkpoints, remote, autopublish, allow_package_substitution, error_on_reject].hash
end

#list_invalid_propertiesObject

Show invalid properties with the reasons. Usually used together with valid?

Returns:

  • Array for valid properties with the reasons



152
153
154
155
156
157
158
159
160
161
162
163
164
165
166
167
168
169
170
171
172
# File 'lib/pulp_python_client/models/patchedpython_python_repository.rb', line 152

def list_invalid_properties
  warn '[DEPRECATED] the `list_invalid_properties` method is obsolete'
  invalid_properties = Array.new
  if !@name.nil? && @name.to_s.length < 1
    invalid_properties.push('invalid value for "name", the character length must be great than or equal to 1.')
  end

  if !@description.nil? && @description.to_s.length < 1
    invalid_properties.push('invalid value for "description", the character length must be great than or equal to 1.')
  end

  if !@retain_repo_versions.nil? && @retain_repo_versions < 1
    invalid_properties.push('invalid value for "retain_repo_versions", must be greater than or equal to 1.')
  end

  if !@retain_checkpoints.nil? && @retain_checkpoints < 1
    invalid_properties.push('invalid value for "retain_checkpoints", must be greater than or equal to 1.')
  end

  invalid_properties
end

#to_bodyHash

to_body is an alias to to_hash (backward compatibility)

Returns:

  • (Hash)

    Returns the object in the form of hash



331
332
333
# File 'lib/pulp_python_client/models/patchedpython_python_repository.rb', line 331

def to_body
  to_hash
end

#to_hashHash

Returns the object in the form of hash

Returns:

  • (Hash)

    Returns the object in the form of hash



337
338
339
340
341
342
343
344
345
346
347
348
349
# File 'lib/pulp_python_client/models/patchedpython_python_repository.rb', line 337

def to_hash
  hash = {}
  self.class.attribute_map.each_pair do |attr, param|
    value = self.send(attr)
    if value.nil?
      is_nullable = self.class.openapi_nullable.include?(attr)
      next if !is_nullable || (is_nullable && !instance_variable_defined?(:"@#{attr}"))
    end

    hash[param] = _to_hash(value)
  end
  hash
end

#to_sString

Returns the string representation of the object

Returns:

  • (String)

    String presentation of the object



325
326
327
# File 'lib/pulp_python_client/models/patchedpython_python_repository.rb', line 325

def to_s
  to_hash.to_s
end

#valid?Boolean

Check to see if the all the properties in the model are valid

Returns:

  • (Boolean)

    true if the model is valid



176
177
178
179
180
181
182
183
# File 'lib/pulp_python_client/models/patchedpython_python_repository.rb', line 176

def valid?
  warn '[DEPRECATED] the `valid?` method is obsolete'
  return false if !@name.nil? && @name.to_s.length < 1
  return false if !@description.nil? && @description.to_s.length < 1
  return false if !@retain_repo_versions.nil? && @retain_repo_versions < 1
  return false if !@retain_checkpoints.nil? && @retain_checkpoints < 1
  true
end