Class: PulpPythonClient::PypiUnyankApi
- Inherits:
-
Object
- Object
- PulpPythonClient::PypiUnyankApi
- Defined in:
- lib/pulp_python_client/api/pypi_unyank_api.rb
Instance Attribute Summary collapse
-
#api_client ⇒ Object
Returns the value of attribute api_client.
Instance Method Summary collapse
-
#initialize(api_client = ApiClient.default) ⇒ PypiUnyankApi
constructor
A new instance of PypiUnyankApi.
-
#unyank(path, yank, opts = {}) ⇒ AsyncOperationResponse
Unyank a package version Unyank a package version, unmarking all its files with data-yanked.
-
#unyank_with_http_info(path, yank, opts = {}) ⇒ Array<(AsyncOperationResponse, Integer, Hash)>
Unyank a package version Unyank a package version, unmarking all its files with data-yanked.
Constructor Details
#initialize(api_client = ApiClient.default) ⇒ PypiUnyankApi
Returns a new instance of PypiUnyankApi.
19 20 21 |
# File 'lib/pulp_python_client/api/pypi_unyank_api.rb', line 19 def initialize(api_client = ApiClient.default) @api_client = api_client end |
Instance Attribute Details
#api_client ⇒ Object
Returns the value of attribute api_client.
17 18 19 |
# File 'lib/pulp_python_client/api/pypi_unyank_api.rb', line 17 def api_client @api_client end |
Instance Method Details
#unyank(path, yank, opts = {}) ⇒ AsyncOperationResponse
Unyank a package version Unyank a package version, unmarking all its files with data-yanked.
29 30 31 32 |
# File 'lib/pulp_python_client/api/pypi_unyank_api.rb', line 29 def unyank(path, yank, opts = {}) data, _status_code, _headers = unyank_with_http_info(path, yank, opts) data end |
#unyank_with_http_info(path, yank, opts = {}) ⇒ Array<(AsyncOperationResponse, Integer, Hash)>
Unyank a package version Unyank a package version, unmarking all its files with data-yanked.
41 42 43 44 45 46 47 48 49 50 51 52 53 54 55 56 57 58 59 60 61 62 63 64 65 66 67 68 69 70 71 72 73 74 75 76 77 78 79 80 81 82 83 84 85 86 87 88 89 90 91 92 93 94 95 96 97 |
# File 'lib/pulp_python_client/api/pypi_unyank_api.rb', line 41 def unyank_with_http_info(path, yank, opts = {}) if @api_client.config.debugging @api_client.config.logger.debug 'Calling API: PypiUnyankApi.unyank ...' end # verify the required parameter 'path' is set if @api_client.config.client_side_validation && path.nil? fail ArgumentError, "Missing the required parameter 'path' when calling PypiUnyankApi.unyank" end # verify the required parameter 'yank' is set if @api_client.config.client_side_validation && yank.nil? fail ArgumentError, "Missing the required parameter 'yank' when calling PypiUnyankApi.unyank" end # resource path local_var_path = '/pypi/{path}/unyank/'.sub('{' + 'path' + '}', CGI.escape(path.to_s).gsub('%2F', '/')) # query parameters query_params = opts[:query_params] || {} # header parameters header_params = opts[:header_params] || {} # HTTP header 'Accept' (if needed) header_params['Accept'] = @api_client.select_header_accept(['application/json']) unless header_params['Accept'] # HTTP header 'Content-Type' content_type = @api_client.select_header_content_type(['application/json', 'application/x-www-form-urlencoded', 'multipart/form-data']) if !content_type.nil? header_params['Content-Type'] = content_type end header_params[:'X-Task-Diagnostics'] = @api_client.build_collection_param(opts[:'x_task_diagnostics'], :csv) if !opts[:'x_task_diagnostics'].nil? # form parameters form_params = opts[:form_params] || {} # http body (model) post_body = opts[:debug_body] || @api_client.object_to_http_body(yank) # return_type return_type = opts[:debug_return_type] || 'AsyncOperationResponse' # auth_names auth_names = opts[:debug_auth_names] || ['basicAuth'] = opts.merge( :operation => :"PypiUnyankApi.unyank", :header_params => header_params, :query_params => query_params, :form_params => form_params, :body => post_body, :auth_names => auth_names, :return_type => return_type ) data, status_code, headers = @api_client.call_api(:POST, local_var_path, ) if @api_client.config.debugging @api_client.config.logger.debug "API called: PypiUnyankApi#unyank\nData: #{data.inspect}\nStatus code: #{status_code}\nHeaders: #{headers}" end return data, status_code, headers end |