Method: PulpPythonClient::RemotesPythonApi#read

Defined in:
lib/pulp_python_client/api/remotes_python_api.rb

#read(python_python_remote_href, opts = {}) ⇒ PythonPythonRemoteResponse

Inspect a python remote

Python Remotes are representations of an external repository of Python content, eg. PyPI.  Fields include upstream repository config. Python Remotes are also used to `sync` from upstream repositories, and contains sync settings.

Parameters:

  • python_python_remote_href (String)
  • opts (Hash) (defaults to: {})

    the optional parameters

Options Hash (opts):

  • :fields (Array<String>)

    A list of fields to include in the response.

  • :exclude_fields (Array<String>)

    A list of fields to exclude from the response.

Returns:



436
437
438
439
# File 'lib/pulp_python_client/api/remotes_python_api.rb', line 436

def read(python_python_remote_href, opts = {})
  data, _status_code, _headers = read_with_http_info(python_python_remote_href, opts)
  data
end