Method: PulpPythonClient::ContentPackagesApi#read_with_http_info
- Defined in:
- lib/pulp_python_client/api/content_packages_api.rb
#read_with_http_info(python_python_package_content_href, opts = {}) ⇒ Array<(PythonPythonPackageContentResponse, Integer, Hash)>
Inspect a python package content
PythonPackageContent represents each individually installable Python package. In the Python ecosystem, this is called a Python Distribution, sometimes (ambiguously) refered to as a package. In Pulp Python, we refer to it as PythonPackageContent. Each PythonPackageContent corresponds to a single filename, for example `pulpcore-3.0.0rc1-py3-none-any.whl` or `pulpcore-3.0.0rc1.tar.gz`.
415 416 417 418 419 420 421 422 423 424 425 426 427 428 429 430 431 432 433 434 435 436 437 438 439 440 441 442 443 444 445 446 447 448 449 450 451 452 453 454 455 456 457 458 459 460 461 462 463 464 |
# File 'lib/pulp_python_client/api/content_packages_api.rb', line 415 def read_with_http_info(python_python_package_content_href, opts = {}) if @api_client.config.debugging @api_client.config.logger.debug 'Calling API: ContentPackagesApi.read ...' end # verify the required parameter 'python_python_package_content_href' is set if @api_client.config.client_side_validation && python_python_package_content_href.nil? fail ArgumentError, "Missing the required parameter 'python_python_package_content_href' when calling ContentPackagesApi.read" end # resource path local_var_path = '{python_python_package_content_href}'.sub('{' + 'python_python_package_content_href' + '}', CGI.escape(python_python_package_content_href.to_s).gsub('%2F', '/')) # query parameters query_params = opts[:query_params] || {} query_params[:'fields'] = @api_client.build_collection_param(opts[:'fields'], :multi) if !opts[:'fields'].nil? query_params[:'exclude_fields'] = @api_client.build_collection_param(opts[:'exclude_fields'], :multi) if !opts[:'exclude_fields'].nil? # header parameters header_params = opts[:header_params] || {} # HTTP header 'Accept' (if needed) header_params['Accept'] = @api_client.select_header_accept(['application/json']) unless header_params['Accept'] header_params[:'X-Task-Diagnostics'] = @api_client.build_collection_param(opts[:'x_task_diagnostics'], :csv) if !opts[:'x_task_diagnostics'].nil? # form parameters form_params = opts[:form_params] || {} # http body (model) post_body = opts[:debug_body] # return_type return_type = opts[:debug_return_type] || 'PythonPythonPackageContentResponse' # auth_names auth_names = opts[:debug_auth_names] || ['basicAuth'] = opts.merge( :operation => :"ContentPackagesApi.read", :header_params => header_params, :query_params => query_params, :form_params => form_params, :body => post_body, :auth_names => auth_names, :return_type => return_type ) data, status_code, headers = @api_client.call_api(:GET, local_var_path, ) if @api_client.config.debugging @api_client.config.logger.debug "API called: ContentPackagesApi#read\nData: #{data.inspect}\nStatus code: #{status_code}\nHeaders: #{headers}" end return data, status_code, headers end |